@@ -30,7 +30,8 @@ import click
 from click_help_colors import HelpColorsCommand, HelpColorsGroup
 
 import molecule.scenarios
-from molecule import config, logger, util
+from molecule import config, logger, text, util
+from molecule.console import should_do_markup
 
 LOG = logger.get_logger(__name__)
 MOLECULE_GLOB = os.environ.get("MOLECULE_GLOB", "molecule/*/molecule.yml")
@@ -50,16 +51,16 @@ class Base(object, metaclass=abc.ABCMeta):
         self._config = c
         self._setup()
 
+    def __init_subclass__(cls) -> None:
+        """Decorate execute from all subclasses."""
+        super().__init_subclass__()
+        for wrapper in logger.get_section_loggers():
+            setattr(cls, "execute", wrapper(cls.execute))
+
     @abc.abstractmethod
     def execute(self):  # pragma: no cover
         pass
 
-    def print_info(self):
-        msg = "Scenario: '{}'".format(self._config.scenario.name)
-        LOG.info(msg)
-        msg = "Action: '{}'".format(util.underscore(self.__class__.__name__))
-        LOG.info(msg)
-
     def _setup(self):
         """
         Prepare Molecule's provisioner and returns None.
@@ -94,7 +95,14 @@ def execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args=()
     scenarios = molecule.scenarios.Scenarios(
         get_configs(args, command_args, ansible_args, glob_str), scenario_name
     )
-    scenarios.print_matrix()
+
+    if scenario_name and scenarios:
+        LOG.info(
+            "%s scenario test matrix: %s",
+            scenario_name,
+            ", ".join(scenarios.sequence(scenario_name)),
+        )
+
     for scenario in scenarios:
         if command_args.get("subcommand") == "reset":
             LOG.info("Removing %s" % scenario.ephemeral_directory)
@@ -125,7 +133,7 @@ def execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args=()
 def execute_subcommand(config, subcommand):
     """Execute subcommand."""
     command_module = getattr(molecule.command, subcommand)
-    command = getattr(command_module, util.camelize(subcommand))
+    command = getattr(command_module, text.camelize(subcommand))
     # knowledge of the current action is used by some provisioners
     # to ensure they behave correctly during certain sequence steps,
     # particulary the setting of ansible options in create/destroy,
@@ -217,7 +225,7 @@ def click_group_ex():
         cls=HelpColorsGroup,
         # Workaround to disable click help line truncation to ~80 chars
         # https://github.com/pallets/click/issues/486
-        context_settings=dict(max_content_width=9999),
+        context_settings=dict(max_content_width=9999, color=should_do_markup()),
         help_headers_color="yellow",
         help_options_color="green",
         help_options_custom_colors={
@@ -229,6 +237,7 @@ def click_group_ex():
             "reset": "blue",
             "test": "bright_yellow",
         },
+        result_callback=result_callback,
     )
 
 
@@ -237,3 +246,10 @@ def click_command_ex() -> Callable[[Callable[..., Any]], click.Command]:
     return click.command(  # type: ignore
         cls=HelpColorsCommand, help_headers_color="yellow", help_options_color="green"
     )
+
+
+def result_callback(*args, **kwargs):
+    """Click natural exit callback."""
+    # We want to be used we run out custom exit code, regardless if run was
+    # a success or failure.
+    util.sysexit(0)
