@@ -19,15 +19,14 @@
 #  DEALINGS IN THE SOFTWARE.
 """Base class used by init command."""
 
-from molecule.command import base
 from molecule import logger
-from molecule.command.init import role
-from molecule.command.init import scenario
+from molecule.command import base
+from molecule.command.init import role, scenario
 
 LOG = logger.get_logger(__name__)
 
 
-@base.click_group_ex()
+@base.click_group_ex()  # type: ignore
 def init():  # pragma: no cover
     """Initialize a new role or scenario."""
 
