@@ -20,8 +20,6 @@
 """Config Module."""
 
 import os
-import subprocess
-import sys
 from uuid import uuid4
 
 from packaging.version import Version
@@ -31,10 +29,11 @@ from molecule.constants import RC_SETUP_ERROR
 from molecule.dependency import ansible_galaxy, shell
 from molecule.model import schema_v3
 from molecule.provisioner import ansible
-from molecule.util import boolean, lru_cache
+from molecule.util import boolean, lru_cache, run_command, sysexit
 
 LOG = logger.get_logger(__name__)
 MOLECULE_DEBUG = boolean(os.environ.get("MOLECULE_DEBUG", "False"))
+MOLECULE_VERBOSITY = int(os.environ.get("MOLECULE_VERBOSITY", 0))
 MOLECULE_DIRECTORY = "molecule"
 MOLECULE_FILE = "molecule.yml"
 MOLECULE_KEEP_STRING = "MOLECULE_"
@@ -421,9 +420,6 @@ class Config(object, metaclass=NewInitCaller):
             msg = f"Failed to validate {self.molecule_file}\n\n{errors}"
             util.sysexit_with_message(msg)
 
-        msg = "Validation completed successfully."
-        LOG.debug(msg)
-
 
 def molecule_directory(path):
     """Return directory of the current scenario."""
@@ -449,7 +445,7 @@ def set_env_from_file(env, env_file):
 
 
 @lru_cache()
-def ansible_version(version: str = None) -> Version:
+def ansible_version(version: str = "") -> Version:
     """Return current Version object for Ansible.
 
     If version is not mentioned, it returns current version as detected.
@@ -457,20 +453,13 @@ def ansible_version(version: str = None) -> Version:
     to Version object in order to make it usable in comparisons.
     """
     if not version:
-        try:
-            version = (
-                subprocess.run(
-                    ["ansible", "--version"],
-                    stdout=subprocess.PIPE,
-                    stderr=subprocess.PIPE,
-                    universal_newlines=True,
-                )
-                .stdout.splitlines()[0]
-                .split()[1]
-            )
-        except FileNotFoundError:
+        proc = run_command(["ansible", "--version"], quiet=True)
+        if proc.returncode == 0:
+            version = proc.stdout.splitlines()[0].split()[1]
+        else:
             LOG.fatal(
-                "Unable to find ansible executable. Read https://molecule.readthedocs.io/en/latest/installation.html"
+                "Unable to find a working copy of ansible executable. Read https://molecule.readthedocs.io/en/latest/installation.html\n%s",
+                proc,
             )
-            sys.exit(RC_SETUP_ERROR)
+            sysexit(RC_SETUP_ERROR)
     return Version(version)
