@@ -1,11 +1,9 @@
 """Ansible Galaxy dependencies for lists of collections."""
 import os
 
-from molecule import logger
-from molecule import util
+from molecule import logger, util
 from molecule.dependency.ansible_galaxy.base import AnsibleGalaxyBase
 
-
 LOG = logger.get_logger(__name__)
 
 
@@ -36,7 +34,7 @@ class Collections(AnsibleGalaxyBase):
     def default_env(self):
         general = super(Collections, self).default_env
         return util.merge_dicts(
-            general, {"ANSIBLE_COLLECTIONS_PATHS": self.install_path}
+            general, {self._config.ansible_collections_path: self.install_path}
         )
 
     @property
