@@ -45,7 +45,7 @@ def pre_validate_base_schema(env, keep_string):
                 "name": {
                     "type": "string",
                     "molecule_env_var": True,
-                    "allowed": ["galaxy", "gilt", "shell"],
+                    "allowed": ["galaxy", "shell"],
                 }
             },
         },
@@ -300,69 +300,6 @@ platforms_docker_schema = {
     }
 }
 
-platforms_podman_schema = {
-    "platforms": {
-        "type": "list",
-        "schema": {
-            "type": "dict",
-            "schema": {
-                "name": {"type": "string"},
-                "hostname": {"type": "string"},
-                "image": {"type": "string"},
-                "dockerfile": {"type": "string"},
-                "pull": {"type": "boolean"},
-                "pre_build_image": {"type": "boolean"},
-                "registry": {
-                    "type": "dict",
-                    "schema": {
-                        "url": {"type": "string"},
-                        "credentials": {
-                            "type": "dict",
-                            "schema": {
-                                "username": {"type": "string"},
-                                "password": {"type": "string"},
-                            },
-                        },
-                    },
-                },
-                "override_command": {"type": "boolean", "nullable": True},
-                "command": {"type": "string", "nullable": True},
-                "tty": {"type": "boolean", "nullable": True},
-                "pid_mode": {"type": "string"},
-                "privileged": {"type": "boolean"},
-                "security_opts": {"type": "list", "schema": {"type": "string"}},
-                "volumes": {"type": "list", "schema": {"type": "string"}},
-                "tmpfs": {"type": "list", "schema": {"type": "string"}},
-                "capabilities": {"type": "list", "schema": {"type": "string"}},
-                "exposed_ports": {
-                    "type": "list",
-                    "schema": {"type": "string", "coerce": "exposed_ports"},
-                },
-                "published_ports": {"type": "list", "schema": {"type": "string"}},
-                "ulimits": {"type": "list", "schema": {"type": "string"}},
-                "dns_servers": {"type": "list", "schema": {"type": "string"}},
-                "etc_hosts": {
-                    "type": ["string", "dict"],
-                    "keysrules": {"type": "string"},
-                },
-                "env": {
-                    "type": "dict",
-                    "keysrules": {"type": "string", "regex": "^[a-zA-Z0-9._-]+$"},
-                },
-                "restart_policy": {"type": "string"},
-                "restart_retries": {"type": "integer"},
-                "network": {"type": "string"},
-                "cert_path": {"type": "string"},
-                "tls_verify": {"type": "boolean"},
-                "cgroup_manager": {"type": "string"},
-                "storage_opt": {"type": "string"},
-                "storage_driver": {"type": "string"},
-                "rootless": {"type": "boolean"},
-            },
-        },
-    }
-}
-
 
 dependency_command_nullable_schema = {
     "dependency": {
@@ -447,12 +384,6 @@ def validate(c):
     if c["dependency"]["name"] == "shell":
         schema = util.merge_dicts(schema, dependency_command_nullable_schema)
 
-    # Driver
-    if c["driver"]["name"] == "docker":
-        schema = util.merge_dicts(schema, platforms_docker_schema)
-    elif c["driver"]["name"] == "podman":
-        schema = util.merge_dicts(schema, platforms_podman_schema)
-
     # Verifier
     schema = util.merge_dicts(schema, api.verifiers()[c["verifier"]["name"]].schema())
 
