@@ -18,9 +18,6 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Ansible-Playbook Provisioner Module."""
-
-import sh
-
 from molecule import logger, util
 
 LOG = logger.get_logger(__name__)
@@ -29,24 +26,18 @@ LOG = logger.get_logger(__name__)
 class AnsiblePlaybook(object):
     """Privisioner Playbook."""
 
-    def __init__(self, playbook, config, out=LOG.out, err=LOG.error):
+    def __init__(self, playbook, config):
         """
         Set up the requirements to execute ``ansible-playbook`` and returns \
         None.
 
         :param playbook: A string containing the path to the playbook.
         :param config: An instance of a Molecule config.
-        :param out: An optional function to process STDOUT for underlying
-         :func:``sh`` call.
-        :param err: An optional function to process STDERR for underlying
-         :func:``sh`` call.
         :returns: None
         """
         self._ansible_command = None
         self._playbook = playbook
         self._config = config
-        self._out = out
-        self._err = err
         self._cli = {}
         self._env = self._config.provisioner.env
 
@@ -69,24 +60,33 @@ class AnsiblePlaybook(object):
             if options.get("become"):
                 del options["become"]
 
-        self._ansible_command = sh.ansible_playbook.bake(
-            options,
-            self._playbook,
-            *verbose_flag,
-            _cwd=self._config.scenario.directory,
-            _env=self._env,
-            _out=self._out,
-            _err=self._err
-        )
+        # We do not pass user-specified Ansible arguments to the create and
+        # destroy invocations because playbooks involved in those two
+        # operations are not always provided by end users. And in those cases,
+        # custom Ansible arguments can break the creation and destruction
+        # processes.
+        #
+        # If users need to modify the creation of deletion, they can supply
+        # custom playbooks and specify them in the scenario configuration.
+        if self._config.action not in ["create", "destroy"]:
+            ansible_args = list(self._config.provisioner.ansible_args) + list(
+                self._config.ansible_args
+            )
+        else:
+            ansible_args = []
 
-        ansible_args = list(self._config.provisioner.ansible_args) + list(
-            self._config.ansible_args
+        self._ansible_command = util.BakedCommand(
+            cmd=[
+                "ansible-playbook",
+                *util.dict2args(options),
+                *util.bool2args(verbose_flag),
+                *ansible_args,
+                self._playbook,  # must always go last
+            ],
+            cwd=self._config.scenario.directory,
+            env=self._env,
         )
 
-        if ansible_args:
-            if self._config.action not in ["create", "destroy"]:
-                self._ansible_command = self._ansible_command.bake(ansible_args)
-
     def execute(self):
         """
         Execute ``ansible-playbook`` and returns a string.
@@ -100,13 +100,15 @@ class AnsiblePlaybook(object):
             LOG.warning("Skipping, %s action has no playbook." % self._config.action)
             return
 
-        try:
-            self._config.driver.sanity_checks()
-            cmd = util.run_command(self._ansible_command, debug=self._config.debug)
-            return cmd.stdout.decode("utf-8")
-        except sh.ErrorReturnCode as e:
-            out = e.stdout.decode("utf-8")
-            util.sysexit_with_message(str(out), e.exit_code)
+        self._config.driver.sanity_checks()
+        result = util.run_command(self._ansible_command, debug=self._config.debug)
+        if result.returncode != 0:
+            util.sysexit_with_message(
+                f"Ansible return code was {result.returncode}, command was: {result.args}",
+                result.returncode,
+            )
+
+        return result.stdout
 
     def add_cli_arg(self, name, value):
         """
