@@ -18,10 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Scenarios Module."""
-
-import operator
-
-import tree_format
+from typing import List
 
 from molecule import logger, util
 
@@ -75,24 +72,16 @@ class Scenarios(object):
         msg = "Test matrix"
         LOG.info(msg)
 
-        tree = tuple(
-            (
-                "",
-                [
-                    (scenario.name, [(action, []) for action in scenario.sequence])
-                    for scenario in self.all
-                ],
-            )
-        )
+        tree = {}
+        for scenario in self.all:
+            tree[scenario.name] = [action for action in scenario.sequence]
+        util.print_as_yaml(tree)
 
-        tf = tree_format.format_tree(
-            tree,
-            format_node=operator.itemgetter(0),
-            get_children=operator.itemgetter(1),
-        )
-
-        LOG.out(tf)
-        LOG.out("")
+    def sequence(self, scenario_name: str) -> List[str]:
+        for scenario in self.all:
+            if scenario.name == scenario_name:
+                return [action for action in scenario.sequence]
+        raise RuntimeError("Unable to find sequence for {scenario_name} scenario.")
 
     def _verify(self):
         """
