@@ -27,11 +27,12 @@ from subprocess import PIPE
 import pexpect
 import pkg_resources
 import pytest
-import sh
 
 from molecule import logger, util
 from molecule.config import ansible_version
 from molecule.test.conftest import change_dir_to
+from molecule.text import strip_ansi_color
+from molecule.util import run_command
 
 LOG = logger.get_logger(__name__)
 
@@ -72,10 +73,9 @@ def with_scenario(request, scenario_to_test, driver_name, scenario_name, skip_te
         yield
         if scenario_name:
             msg = "CLEANUP: Destroying instances for all scenario(s)"
-            LOG.out(msg)
-            options = {"driver_name": driver_name, "all": True}
-            cmd = sh.molecule.bake("destroy", **options)
-            pytest.helpers.run_command(cmd)
+            LOG.info(msg)
+            cmd = ["molecule", "destroy", "--driver-name", driver_name, "--all"]
+            assert run_command(cmd).returncode == 0
 
 
 @pytest.fixture
@@ -94,39 +94,35 @@ def skip_test(request, driver_name):
 
 @pytest.helpers.register
 def idempotence(scenario_name):
-    options = {"scenario_name": scenario_name}
-    cmd = sh.molecule.bake("create", **options)
-    pytest.helpers.run_command(cmd)
+    cmd = ["molecule", "create", "--scenario-name", scenario_name]
+    assert run_command(cmd).returncode == 0
 
-    options = {"scenario_name": scenario_name}
-    cmd = sh.molecule.bake("converge", **options)
-    pytest.helpers.run_command(cmd)
+    cmd = ["molecule", "converge", "--scenario-name", scenario_name]
+    assert run_command(cmd).returncode == 0
 
-    options = {"scenario_name": scenario_name}
-    cmd = sh.molecule.bake("idempotence", **options)
-    pytest.helpers.run_command(cmd)
+    cmd = ["molecule", "idempotence", "--scenario-name", scenario_name]
+    assert run_command(cmd).returncode == 0
 
 
 @pytest.helpers.register
 def init_role(temp_dir, driver_name):
     role_directory = os.path.join(temp_dir.strpath, "test-init")
 
-    cmd = sh.molecule.bake("init", "role", "test-init", {"driver-name": driver_name})
-    pytest.helpers.run_command(cmd)
+    cmd = ["molecule", "init", "role", "test-init", "--driver-name", driver_name]
+    assert run_command(cmd).returncode == 0
     pytest.helpers.metadata_lint_update(role_directory)
 
     with change_dir_to(role_directory):
-        options = {"all": True}
-        cmd = sh.molecule.bake("test", **options)
-        pytest.helpers.run_command(cmd)
+        cmd = ["molecule", "test", "--all"]
+        assert run_command(cmd).returncode == 0
 
 
 @pytest.helpers.register
 def init_scenario(temp_dir, driver_name):
     # Create role
     role_directory = os.path.join(temp_dir.strpath, "test-init")
-    cmd = sh.molecule.bake("init", "role", "test-init", {"driver-name": driver_name})
-    pytest.helpers.run_command(cmd)
+    cmd = ["molecule", "init", "role", "test-init", "--driver-name", driver_name]
+    assert run_command(cmd).returncode == 0
     pytest.helpers.metadata_lint_update(role_directory)
 
     with change_dir_to(role_directory):
@@ -134,15 +130,22 @@ def init_scenario(temp_dir, driver_name):
         molecule_directory = pytest.helpers.molecule_directory()
         scenario_directory = os.path.join(molecule_directory, "test-scenario")
 
-        options = {"role-name": "test-init", "driver-name": driver_name}
-        cmd = sh.molecule.bake("init", "scenario", "test-scenario", **options)
-        pytest.helpers.run_command(cmd)
+        cmd = [
+            "molecule",
+            "init",
+            "scenario",
+            "test-scenario",
+            "--role-name",
+            "test-init",
+            "--driver-name",
+            driver_name,
+        ]
+        assert run_command(cmd).returncode == 0
 
         assert os.path.isdir(scenario_directory)
 
-        options = {"scenario_name": "test-scenario", "all": True}
-        cmd = sh.molecule.bake("test", **options)
-        pytest.helpers.run_command(cmd)
+        cmd = ["molecule", "test", "--scenario-name", "test-scenario", "--all"]
+        assert run_command(cmd).returncode == 0
 
 
 @pytest.helpers.register
@@ -163,16 +166,16 @@ def metadata_lint_update(role_directory):
     # of the role directory and pointed at the role directory to ensure
     # the customize ansible-lint config is used.
     with change_dir_to(role_directory):
-        cmd = sh.ansible_lint.bake(".")
-    pytest.helpers.run_command(cmd)
+        cmd = ["ansible-lint", "."]
+    assert run_command(cmd).returncode == 0
 
 
 @pytest.helpers.register
 def list(x):
-    cmd = sh.molecule.bake("list")
-    out = pytest.helpers.run_command(cmd, log=False)
-    out = out.stdout.decode("utf-8")
-    out = util.strip_ansi_color(out)
+    cmd = ["molecule", "list"]
+    result = run_command(cmd)
+    assert result.returncode == 0
+    out = util.strip_ansi_color(result.stdout)
 
     for l in x.splitlines():
         assert l in out
@@ -180,10 +183,9 @@ def list(x):
 
 @pytest.helpers.register
 def list_with_format_plain(x):
-    cmd = sh.molecule.bake("list", {"format": "plain"})
-    out = pytest.helpers.run_command(cmd, log=False)
-    out = out.stdout.decode("utf-8")
-    out = util.strip_ansi_color(out)
+    cmd = ["molecule", "list", "--format", "plain"]
+    result = util.run_command(cmd)
+    out = strip_ansi_color(result.stdout)
 
     for l in x.splitlines():
         assert l in out
@@ -191,13 +193,11 @@ def list_with_format_plain(x):
 
 @pytest.helpers.register
 def login(login_args, scenario_name="default"):
-    options = {"scenario_name": scenario_name}
-    cmd = sh.molecule.bake("destroy", **options)
-    pytest.helpers.run_command(cmd)
+    cmd = ["molecule", "destroy", "--scenario-name", scenario_name]
+    assert run_command(cmd).returncode == 0
 
-    options = {"scenario_name": scenario_name}
-    cmd = sh.molecule.bake("create", **options)
-    pytest.helpers.run_command(cmd)
+    cmd = ["molecule", "create", "--scenario-name", scenario_name]
+    assert run_command(cmd).returncode == 0
 
     for instance, regexp in login_args:
         if len(login_args) > 1:
@@ -214,32 +214,26 @@ def login(login_args, scenario_name="default"):
 
 @pytest.helpers.register
 def test(driver_name, scenario_name="default", parallel=False):
-    options = {
-        "scenario_name": scenario_name,
-        "all": scenario_name is None,
-        "parallel": parallel,
-    }
+    cmd = ["molecule", "test", "--scenario-name", scenario_name]
+    if driver_name != "delegated":
+        if scenario_name is None:
+            cmd.append("--all")
+        if parallel:
+            cmd.append("--parallel")
 
-    if driver_name == "delegated":
-        options = {"scenario_name": scenario_name}
-
-    cmd = sh.molecule.bake("test", **options)
-    pytest.helpers.run_command(cmd)
+    assert run_command(cmd).returncode == 0
 
 
 @pytest.helpers.register
 def verify(scenario_name="default"):
-    options = {"scenario_name": scenario_name}
-    cmd = sh.molecule.bake("create", **options)
-    pytest.helpers.run_command(cmd)
+    cmd = ["molecule", "create", "--scenario-name", scenario_name]
+    assert run_command(cmd).returncode == 0
 
-    options = {"scenario_name": scenario_name}
-    cmd = sh.molecule.bake("converge", **options)
-    pytest.helpers.run_command(cmd)
+    cmd = ["molecule", "converge", "--scenario-name", scenario_name]
+    assert run_command(cmd).returncode == 0
 
-    options = {"scenario_name": scenario_name}
-    cmd = sh.molecule.bake("verify", **options)
-    pytest.helpers.run_command(cmd)
+    cmd = ["molecule", "verify", "--scenario-name", scenario_name]
+    assert run_command(cmd).returncode == 0
 
 
 def get_docker_executable():
