@@ -24,41 +24,22 @@ import binascii
 import io
 import os
 
-import colorama
 import pytest
-import sh
 
 from molecule import util
+from molecule.console import console
 from molecule.constants import MOLECULE_HEADER
-
-colorama.init(autoreset=True)
+from molecule.text import strip_ansi_escape
 
 
-def test_print_debug(capsys):
-    util.print_debug("test_title", "test_data")
-    result, _ = capsys.readouterr()
-    title = [
-        colorama.Back.WHITE,
-        colorama.Style.BRIGHT,
-        colorama.Fore.BLACK,
-        "DEBUG: test_title",
-        colorama.Fore.RESET,
-        colorama.Back.RESET,
-        colorama.Style.RESET_ALL,
-    ]
-    print("".join(title))
+def test_print_debug():
 
-    data = [
-        colorama.Fore.BLACK,
-        colorama.Style.BRIGHT,
-        "test_data",
-        colorama.Style.RESET_ALL,
-        colorama.Fore.RESET,
-    ]
-    print("".join(data))
+    expected = "DEBUG: test_title:\ntest_data\n"
+    with console.capture() as capture:
+        util.print_debug("test_title", "test_data")
 
-    x, _ = capsys.readouterr()
-    assert x == result
+    result = strip_ansi_escape(capture.get())
+    assert result == expected
 
 
 def test_print_environment_vars(capsys):
@@ -70,72 +51,22 @@ def test_print_environment_vars(capsys):
         "MOLECULE_BAR": "bar",
         "MOLECULE": None,
     }
-    util.print_environment_vars(env)
-    result, _ = capsys.readouterr()
+    expected = """DEBUG: ANSIBLE ENVIRONMENT:
+ANSIBLE_BAR: bar
+ANSIBLE_FOO: foo
 
-    # Ansible Environment
-    title = [
-        colorama.Back.WHITE,
-        colorama.Style.BRIGHT,
-        colorama.Fore.BLACK,
-        "DEBUG: ANSIBLE ENVIRONMENT",
-        colorama.Fore.RESET,
-        colorama.Back.RESET,
-        colorama.Style.RESET_ALL,
-    ]
-    print("".join(title))
-    data = [
-        colorama.Fore.BLACK,
-        colorama.Style.BRIGHT,
-        util.safe_dump({"ANSIBLE_FOO": "foo", "ANSIBLE_BAR": "bar"}),
-        colorama.Style.RESET_ALL,
-        colorama.Fore.RESET,
-    ]
-    print("".join(data))
+DEBUG: MOLECULE ENVIRONMENT:
+MOLECULE_BAR: bar
+MOLECULE_FOO: foo
 
-    # Molecule Environment
-    title = [
-        colorama.Back.WHITE,
-        colorama.Style.BRIGHT,
-        colorama.Fore.BLACK,
-        "DEBUG: MOLECULE ENVIRONMENT",
-        colorama.Fore.RESET,
-        colorama.Back.RESET,
-        colorama.Style.RESET_ALL,
-    ]
-    print("".join(title))
-    data = [
-        colorama.Fore.BLACK,
-        colorama.Style.BRIGHT,
-        util.safe_dump({"MOLECULE_FOO": "foo", "MOLECULE_BAR": "bar"}),
-        colorama.Style.RESET_ALL,
-        colorama.Fore.RESET,
-    ]
-    print("".join(data))
+DEBUG: SHELL REPLAY:
+ANSIBLE_BAR=bar ANSIBLE_FOO=foo MOLECULE_BAR=bar MOLECULE_FOO=foo
+"""
 
-    # Shell Replay
-    title = [
-        colorama.Back.WHITE,
-        colorama.Style.BRIGHT,
-        colorama.Fore.BLACK,
-        "DEBUG: SHELL REPLAY",
-        colorama.Fore.RESET,
-        colorama.Back.RESET,
-        colorama.Style.RESET_ALL,
-    ]
-    print("".join(title))
-    data = [
-        colorama.Fore.BLACK,
-        colorama.Style.BRIGHT,
-        "ANSIBLE_BAR=bar ANSIBLE_FOO=foo MOLECULE_BAR=bar MOLECULE_FOO=foo",
-        colorama.Style.RESET_ALL,
-        colorama.Fore.RESET,
-    ]
-    print("".join(data))
-    print()
-
-    x, _ = capsys.readouterr()
-    assert x == result
+    with console.capture() as capture:
+        util.print_environment_vars(env)
+    result = strip_ansi_escape(capture.get())
+    assert result == expected
 
 
 def test_sysexit():
@@ -171,34 +102,29 @@ def test_sysexit_with_message_and_custom_code(patched_logger_critical):
 
 
 def test_run_command():
-    cmd = sh.ls.bake()
+    cmd = ["ls"]
     x = util.run_command(cmd)
 
-    assert 0 == x.exit_code
+    assert 0 == x.returncode
 
 
 def test_run_command_with_debug(mocker, patched_print_debug):
-    cmd = sh.ls.bake(_env={"ANSIBLE_FOO": "foo", "MOLECULE_BAR": "bar"})
-    util.run_command(cmd, debug=True)
+    env = {"ANSIBLE_FOO": "foo", "MOLECULE_BAR": "bar"}
+    util.run_command(["ls"], debug=True, env=env)
     x = [
-        mocker.call("ANSIBLE ENVIRONMENT", "---\nANSIBLE_FOO: foo\n"),
-        mocker.call("MOLECULE ENVIRONMENT", "---\nMOLECULE_BAR: bar\n"),
+        mocker.call("ANSIBLE ENVIRONMENT", "ANSIBLE_FOO: foo\n"),
+        mocker.call("MOLECULE ENVIRONMENT", "MOLECULE_BAR: bar\n"),
         mocker.call("SHELL REPLAY", "ANSIBLE_FOO=foo MOLECULE_BAR=bar"),
-        mocker.call("COMMAND", sh.which("ls")),
     ]
 
     assert x == patched_print_debug.mock_calls
 
 
 def test_run_command_with_debug_handles_no_env(mocker, patched_print_debug):
-    cmd = sh.ls.bake()
+    cmd = "ls"
     util.run_command(cmd, debug=True)
-    x = [
-        mocker.call("ANSIBLE ENVIRONMENT", "--- {}\n"),
-        mocker.call("MOLECULE ENVIRONMENT", "--- {}\n"),
-        mocker.call("SHELL REPLAY", ""),
-        mocker.call("COMMAND", sh.which("ls")),
-    ]
+    # when env is empty we expect not to print anything
+    x = []
 
     assert x == patched_print_debug.mock_calls
 
@@ -304,18 +230,6 @@ def test_instance_with_scenario_name():
     assert "foo-bar" == util.instance_with_scenario_name("foo", "bar")
 
 
-def test_strip_ansi_escape():
-    string = "ls\r\n\x1b[00m\x1b[01;31mfoo\x1b[00m\r\n\x1b[01;31m"
-
-    assert "ls\r\nfoo\r\n" == util.strip_ansi_escape(string)
-
-
-def test_strip_ansi_color():
-    s = "foo\x1b[0m\x1b[0m\x1b[0m\n\x1b[0m\x1b[0m\x1b[0m\x1b[0m\x1b[0m"
-
-    assert "foo\n" == util.strip_ansi_color(s)
-
-
 def test_verbose_flag():
     options = {"verbose": True, "v": True}
 
@@ -351,11 +265,6 @@ def test_filter_verbose_permutation():
     assert x == util.filter_verbose_permutation(options)
 
 
-def test_title():
-    assert "Foo" == util.title("foo")
-    assert "Foo Bar" == util.title("foo_bar")
-
-
 def test_abs_path(temp_dir):
     x = os.path.abspath(os.path.join(os.getcwd(), os.path.pardir, "foo", "bar"))
 
@@ -366,18 +275,6 @@ def test_abs_path_with_none_path():
     assert util.abs_path(None) is None
 
 
-def test_camelize():
-    assert "Foo" == util.camelize("foo")
-    assert "FooBar" == util.camelize("foo_bar")
-    assert "FooBarBaz" == util.camelize("foo_bar_baz")
-
-
-def test_underscore():
-    assert "foo" == util.underscore("Foo")
-    assert "foo_bar" == util.underscore("FooBar")
-    assert "foo_bar_baz" == util.underscore("FooBarBaz")
-
-
 @pytest.mark.parametrize(
     "a,b,x",
     [
