@@ -26,13 +26,17 @@ import os
 import re
 import sys
 from collections.abc import Mapping
+from dataclasses import dataclass
 from functools import lru_cache  # noqa
-from typing import Any, Dict, Optional
+from subprocess import CompletedProcess
+from typing import Any, Dict, List, NoReturn, Optional, Union
 
-import colorama
 import jinja2
 import yaml
+from rich.syntax import Syntax
+from subprocess_tee import run
 
+from molecule.console import console
 from molecule.constants import MOLECULE_HEADER
 from molecule.logger import get_logger
 
@@ -46,30 +50,12 @@ class SafeDumper(yaml.SafeDumper):
         return super(SafeDumper, self).increase_indent(flow, False)
 
 
-def print_debug(title, data):
+def print_debug(title: str, data: str) -> None:
     """Print debug information."""
-    title = "DEBUG: {}".format(title)
-    title = [
-        colorama.Back.WHITE,
-        colorama.Style.BRIGHT,
-        colorama.Fore.BLACK,
-        title,
-        colorama.Fore.RESET,
-        colorama.Back.RESET,
-        colorama.Style.RESET_ALL,
-    ]
-    print("".join(title))
-    data = [
-        colorama.Fore.BLACK,
-        colorama.Style.BRIGHT,
-        data,
-        colorama.Style.RESET_ALL,
-        colorama.Fore.RESET,
-    ]
-    print("".join(data))
+    console.print(f"DEBUG: {title}:\n{data}")
 
 
-def print_environment_vars(env):
+def print_environment_vars(env: Optional[Dict[str, str]]) -> None:
     """
     Print ``Ansible`` and ``Molecule`` environment variables and returns None.
 
@@ -77,23 +63,32 @@ def print_environment_vars(env):
     ``os.environ``.
     :return: None
     """
-    ansible_env = {k: v for (k, v) in env.items() if "ANSIBLE_" in k}
-    print_debug("ANSIBLE ENVIRONMENT", safe_dump(ansible_env))
+    if env:
+        ansible_env = {k: v for (k, v) in env.items() if "ANSIBLE_" in k}
+        print_debug("ANSIBLE ENVIRONMENT", safe_dump(ansible_env, explicit_start=False))
 
-    molecule_env = {k: v for (k, v) in env.items() if "MOLECULE_" in k}
-    print_debug("MOLECULE ENVIRONMENT", safe_dump(molecule_env))
+        molecule_env = {k: v for (k, v) in env.items() if "MOLECULE_" in k}
+        print_debug(
+            "MOLECULE ENVIRONMENT", safe_dump(molecule_env, explicit_start=False)
+        )
 
-    combined_env = ansible_env.copy()
-    combined_env.update(molecule_env)
-    print_debug(
-        "SHELL REPLAY",
-        " ".join(["{}={}".format(k, v) for (k, v) in sorted(combined_env.items())]),
-    )
-    print()
+        combined_env = ansible_env.copy()
+        combined_env.update(molecule_env)
+        print_debug(
+            "SHELL REPLAY",
+            " ".join(["{}={}".format(k, v) for (k, v) in sorted(combined_env.items())]),
+        )
+        print()
 
 
-def sysexit(code: int = 1) -> None:
+def sysexit(code: int = 1) -> NoReturn:
     """Perform a system exit with given code, default 1."""
+    if "MOLECULE_REPORT" in os.environ:
+        report_file = os.environ["MOLECULE_REPORT"]
+        LOG.info("Writing %s report.", report_file)
+        with open(report_file, "w") as f:
+            f.write(console.export_html())
+
     sys.exit(code)
 
 
@@ -113,21 +108,40 @@ def sysexit_with_message(
     sysexit(code)
 
 
-def run_command(cmd, debug=False):
+def run_command(
+    cmd, env=None, debug=False, echo=False, quiet=False
+) -> CompletedProcess:
     """
     Execute the given command and returns None.
 
-    :param cmd: A ``sh.Command`` object to execute.
+    :param cmd: :
+        - a string or list of strings (similar to subprocess.run)
+        - a BakedCommand object (
     :param debug: An optional bool to toggle debug output.
     :return: ``sh`` object
     """
+    args = []
+    stdout = None
+    stderr = None
+    if cmd.__class__.__name__ == "Command":
+        raise RuntimeError(
+            "Molecule 3.2.0 dropped use of sh library, update plugin code to use new API. "
+            "See https://github.com/ansible-community/molecule/issues/2678"
+        )
+    elif cmd.__class__.__name__ == "BakedCommand":
+        env = cmd.env if not env else cmd.env.copy().update(env)
+        args = cmd.cmd
+        stdout = cmd.stdout
+        stderr = cmd.stderr
+    else:
+        args = cmd
+
     if debug:
-        # WARN(retr0h): Uses an internal ``sh`` data structure to dig
-        # the environment out of the ``sh.command`` object.
-        print_environment_vars(cmd._partial_call_args.get("env", {}))
-        print_debug("COMMAND", str(cmd))
-        print()
-    return cmd(_truncate_exc=False)
+        print_environment_vars(env)
+
+    return run(
+        args, env=env, stdout=stdout, stderr=stderr, echo=echo or debug, quiet=quiet
+    )
 
 
 def os_walk(directory, pattern, excludes=[]):
@@ -182,18 +196,15 @@ def file_prepender(filename):
         f.write(molecule_prepender(content))
 
 
-def safe_dump(data: Any) -> str:
+def safe_dump(data: Any, explicit_start=True) -> str:
     """
     Dump the provided data to a YAML document and returns a string.
 
     :param data: A string containing an absolute path to the file to parse.
     :return: str
     """
-    # TODO(retr0h): Do we need to encode?
-    # yaml.dump(data) produces the document as a str object in both python
-    # 2 and 3.
     return yaml.dump(
-        data, Dumper=SafeDumper, default_flow_style=False, explicit_start=True
+        data, Dumper=SafeDumper, default_flow_style=False, explicit_start=explicit_start
     )
 
 
@@ -240,29 +251,6 @@ def instance_with_scenario_name(instance_name, scenario_name):
     return "{}-{}".format(instance_name, scenario_name)
 
 
-def strip_ansi_escape(data):
-    """Remove all ANSI escapes from string or bytes.
-
-    If bytes is passed instead of string, it will be converted to string
-    using UTF-8.
-    """
-    if isinstance(data, bytes):
-        data = data.decode("utf-8")
-
-    return re.sub(r"\x1b[^m]*m", "", data)
-
-
-def strip_ansi_color(data):
-    """Remove ANSI colors from string or bytes."""
-    if isinstance(data, bytes):
-        data = data.decode("utf-8")
-
-    # Taken from tabulate
-    invisible_codes = re.compile(r"\x1b\[\d*m")
-
-    return re.sub(invisible_codes, "", data)
-
-
 def verbose_flag(options):
     """Return computed verbosity flag."""
     verbose = "v"
@@ -284,35 +272,12 @@ def filter_verbose_permutation(options):
     return {k: options[k] for k in options if not re.match("^[v]+$", k)}
 
 
-def title(word):
-    """Format title."""
-    return " ".join(x.capitalize() or "_" for x in word.split("_"))
-
-
 def abs_path(path):
     """Return absolute path."""
     if path:
         return os.path.abspath(path)
 
 
-def camelize(string):
-    """Format string as camel-case."""
-    # NOTE(retr0h): Taken from jpvanhal/inflection
-    # https://github.com/jpvanhal/inflection
-    return re.sub(r"(?:^|_)(.)", lambda m: m.group(1).upper(), string)
-
-
-def underscore(string):
-    """Format string to underlined notation."""
-    # NOTE(retr0h): Taken from jpvanhal/inflection
-    # https://github.com/jpvanhal/inflection
-    string = re.sub(r"([A-Z]+)([A-Z][a-z])", r"\1_\2", string)
-    string = re.sub(r"([a-z\d])([A-Z])", r"\1_\2", string)
-    string = string.replace("-", "_")
-
-    return string.lower()
-
-
 def merge_dicts(a, b):
     """
     Merge the values of b into a and returns a new dict.
@@ -393,3 +358,39 @@ def boolean(value: Any, strict=True) -> bool:
         "The value '%s' is not a valid boolean.  Valid booleans include: %s"
         % (str(value), ", ".join(repr(i) for i in BOOLEANS))
     )
+
+
+@dataclass
+class BakedCommand:
+    """Define a subprocess command to be executed."""
+
+    cmd: Union[str, List[str]]
+    env: Optional[Dict]
+    cwd: Optional[str] = None
+    stdout: Any = None
+    stderr: Any = None
+
+
+def dict2args(data: Dict) -> List[str]:
+    """Convert a dictionary of options to command like arguments."""
+    result = []
+    # keep sorting in order to achieve a predictable behavior
+    for k, v in sorted(data.items()):
+        if v is not False:
+            prefix = "-" if len(k) == 1 else "--"
+            result.append(f"{prefix}{k}".replace("_", "-"))
+            if v is not True:
+                # { foo: True } should produce --foo without any values
+                result.append(v)
+    return result
+
+
+def bool2args(data: bool) -> List[str]:
+    """Convert a boolean value to command line argument (flag)."""
+    return []
+
+
+def print_as_yaml(data: Any) -> None:
+    """Render python object as yaml on console."""
+    result = Syntax(safe_dump(data), "yaml")
+    console.print(result)
